@@ -1,10 +1,7 @@
 /*
-  $Id: folialint.cxx 17689 2014-09-22 13:06:25Z sloot $
-  $URL: https://ilk.uvt.nl/svn/sources/libfolia/trunk/src/folialint.cxx $
-
-  Copyright (c) 1998 - 2014
+  Copyright (c) 2006 - 2016
+  CLST  - Radboud University
   ILK   - Tilburg University
-  CLiPS - University of Antwerp
 
   This file is part of libfolia
 
@@ -22,44 +19,55 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/ticcutils/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
+
 */
 
 #include <iostream>
 #include <fstream>
 #include <string>
-#include <map>
 #include "ticcutils/CommandLine.h"
-#include "libfolia/document.h"
+#include "libfolia/folia.h"
 
 using namespace std;
 
 void usage(){
-  cerr << "usage: folialint [options] <foliafile> [<outputfile>]" << endl;
+  cerr << "usage: folialint [options] <foliafiles>" << endl;
 }
 
 int main( int argc, char* argv[] ){
-  string inputName;
   string outputName;
   bool permissive;
+  bool strip;
+  bool nooutput = false;
   string debug;
   vector<string> fileNames;
   try {
-    TiCC::CL_Options Opts( "hV", "debug:,permissive");
+    TiCC::CL_Options Opts( "hV",
+			   "debug:,permissive,strip,output:,nooutput,help,version");
     Opts.init(argc, argv );
-    if ( Opts.extract( 'h' ) ){
+    if ( Opts.extract( 'h' )
+	 || Opts.extract( "help" ) ){
       usage();
       return EXIT_SUCCESS;
     }
-    if ( Opts.extract( 'V' ) ){
-      cout << "folialint version 0.2" << endl;
+    if ( Opts.extract( 'V' )
+	 || Opts.extract( "version" ) ){
+      cout << "folialint version 0.4" << endl;
       cout << "based on [" << folia::VersionName() << "]" << endl;
       return EXIT_SUCCESS;
     }
     permissive = Opts.extract("permissive");
+    nooutput = Opts.extract("nooutput");
+    strip = Opts.extract("strip");
+    if ( strip && permissive ){
+      cerr << "conflicting options: 'permissive' and 'strip'" << endl;
+      return EXIT_FAILURE;
+    }
     Opts.extract( "debug", debug );
+    Opts.extract("output", outputName);
     if ( !Opts.empty() ){
       cerr << "unsupported option(s): " << Opts.toString() << endl;
       return EXIT_FAILURE;
@@ -69,14 +77,11 @@ int main( int argc, char* argv[] ){
       cerr << "missing input file" << endl;
       return EXIT_FAILURE;
     }
-    if ( fileNames.size() > 2 ){
-      cerr << "expected 1 input file, and 1 output file" << endl;
+    if ( fileNames.size() > 1 && !outputName.empty() ){
+      cerr << "--outputname not supported for more then 1 inputfile" << endl;
       return EXIT_FAILURE;
     }
-    inputName = fileNames[0];
-    if ( fileNames.size() == 2 ){
-      outputName = fileNames[1];
-    }
+    string inputName = fileNames[0];
     if ( inputName == outputName ){
       cerr << "output name cannot be same as input name!" << endl;
       return EXIT_FAILURE;
@@ -86,21 +91,27 @@ int main( int argc, char* argv[] ){
     cerr << "FAIL: " << e.what() << endl;
     exit( EXIT_FAILURE );
   }
-  try {
-    string cmd = "file='" + inputName + "'";
-    if ( !debug.empty() )
-      cmd += ", debug='" + debug + "'";
-    if ( permissive )
-      cmd += ", mode='permissive'";
-    folia::Document d( cmd );
-    if ( !outputName.empty() )
-      d.save( outputName );
-    else
-      cout << d;
-  }
-  catch( exception& e ){
-    cerr << "FAIL: " << e.what() << endl;
-    exit( EXIT_FAILURE );
+  for ( const auto& inputName : fileNames ){
+    try {
+      string cmd = "file='" + inputName + "'";
+      if ( !debug.empty() )
+	cmd += ", debug='" + debug + "'";
+      if ( permissive )
+	cmd += ", mode='permissive'";
+      else if ( strip )
+	cmd += ", mode='strip'";
+      folia::Document d( cmd );
+      if ( !outputName.empty() ){
+	d.save( outputName );
+      }
+      else if ( !nooutput ){
+	cout << d;
+      }
+    }
+    catch( exception& e ){
+      cerr << "FAIL: " << e.what() << endl;
+      exit( EXIT_FAILURE );
+    }
   }
   exit( EXIT_SUCCESS );
 }
