@@ -1,10 +1,7 @@
 /*
-  $Id: simpletest.cxx 17507 2014-08-13 15:20:36Z sloot $
-  $URL: https://ilk.uvt.nl/svn/sources/libfolia/trunk/src/simpletest.cxx $
-
-  Copyright (c) 1998 - 2014
+  Copyright (c) 2006 - 2016
+  CLST  - Radboud University
   ILK   - Tilburg University
-  CLiPS - University of Antwerp
 
   This file is part of libfolia
 
@@ -22,15 +19,17 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/ticcutils/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
+
 */
 
 #include <iostream>
 #include <string>
 #include <map>
-#include "libfolia/document.h"
+#include "ticcutils/StringOps.h"
+#include "libfolia/folia.h"
 
 using namespace std;
 using namespace folia;
@@ -39,12 +38,12 @@ int main() {
   cout << "checking sanity" << endl;
   cout << "AnnotationType sanity" << endl;
   if ( ! AT_sanity_check() ){
-    cout << "to bad. no use to continue" << endl;
+    cout << "too bad. no use to continue" << endl;
     return EXIT_FAILURE;
   }
   cout << "ElementType sanity" << endl;
   if ( ! ET_sanity_check() ){
-    cout << "to bad. no use to continue" << endl;
+    cout << "too bad. no use to continue" << endl;
     return EXIT_FAILURE;
   }
   cout << " Creating a document from scratch: ";
@@ -53,13 +52,15 @@ int main() {
   if ( d.defaultset(AnnotationType::TOKEN) != "adhocset"
        ||
        d.defaultannotator(AnnotationType::TOKEN) != "proycon" ){
+    cout << " Defaultset or defaultannotator does not match" << endl;
     return EXIT_FAILURE;
   }
   string id = d.id() + ".text.1";
   KWargs kw = getArgs( "id='" + id + "'" );
   FoliaElement *text = d.addText( kw );
   kw.clear();
-  FoliaElement *s = new Sentence( &d, "generate_id='" + text->id() + "'" );
+  kw = getArgs( "generate_id='" + text->id() + "'" );
+  FoliaElement *s = new Sentence( kw, &d );
   text->append( s );
   kw.clear();
   kw["text"] = "De";
@@ -72,11 +73,15 @@ int main() {
   s->addWord( kw );
   kw["text"] = ".";
   s->addWord( kw );
-  if ( d[id+".s.1"]->size() != 5 )
+  if ( d[id+".s.1"]->size() != 5 ) {
+    cout << " Unexpected sentence size, " <<  d[id+".s.1"]->size() << ", expected 5" << endl;
     return EXIT_FAILURE;
+  }
   UnicodeString txt = s->text();
-  if ( txt != "De site staat online ." )
+  if ( txt != "De site staat online ." ) {
+    cout << " Text does not match reference: '" << txt << "' vs reference: 'De site staat online .'" << endl;
     return EXIT_FAILURE;
+  }
   cout << s->text() << endl;
   return EXIT_SUCCESS;
 }
